Flaskquotes
===========

A quote generator built with Flask and BeautifulSoup. Quotes are scraped from the American
Film Institute's top 100 movie quotes list.

Installation
------------

To install, simply run `pip install flaskquotes`.

Usage
-----

This project is a web application, but it includes a command line entrypoint called `quotes`.
After installation, run `quotes` for a random quote, or include the `--random` option for a
random quote.

Bugs and Modifications
----------------------

Please feel free to email me at jeff.moorhead1@gmail.com with ideas for modifications or to
report a bug.
